# PROMINENCE Command Line Interface

![License](https://img.shields.io/github/license/prominence-eosc/cli)
[![PyPI version shields.io](https://img.shields.io/pypi/v/prominence.svg)](https://pypi.python.org/pypi/ansicolortags/)

The PROMINENCE CLI presents a simple batch-system style interface to PROMINENCE. Written in Python, it can be installed easily on any system using pip:
```
pip install prominence
```
To upgrade the CLI the `--upgrade` option needs to be added:
```
pip install --upgrade prominence
```

See https://prominence-eosc.github.io/docs/ for more information.
